summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--firmware/target/arm/as3525/system-as3525.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/firmware/target/arm/as3525/system-as3525.c b/firmware/target/arm/as3525/system-as3525.c
index ba817b4..dc335df 100644
--- a/firmware/target/arm/as3525/system-as3525.c
+++ b/firmware/target/arm/as3525/system-as3525.c
@@ -338,9 +338,9 @@ void set_cpu_frequency(long frequency)
/* Increasing frequency so boost voltage before change */
ascodec_write(AS3514_CVDD_DCDC3, (AS314_CP_DCDC3_SETTING | CVDD_1_20));
- /* Wait for voltage to be at least 1.20v before making fclk > 200 MHz */
- while(adc_read(ADC_CVDD) < 480) /* 480 * .0025 = 1.20V */
- ;
+ /* Some players run a bit low so use 1.175 volts instead of 1.20 */
+ /* Wait for voltage to be at least 1.175v before making fclk > 200 MHz */
+ while(adc_read(ADC_CVDD) < 470); /* 470 * .0025 = 1.175V */
asm volatile(
"mrc p15, 0, r0, c1, c0 \n"